*******************************************************************;
**              --     FARSLD99.SAS    ---                      ***;
**   SAS Program to convert 1999 FARS Files to SAS Format       ***;
**      using SAS PC.                                           ***;
**                                                              ***;
*******************************************************************;
**                                                              ***;
**                 Input file names and paths                   ***;
**        I:  --> drive number                                  ***;
** FARS93.SEQ --> dataset name of FARS flat data input file     ***;
**    path1   --> location of FARS flat data input file         ***;
**    path2   --> location of FARS SAS output files             ***;
**    path3   --> location of FARS SAS FORMAT files             ***;
**        sas output files will be named:                       ***;
**         ACCIDENT.SSD on path1  for the ACCIDENT level file   ***;
**          VEHICLE.SSD on path1  for the VEHICLE  level file   ***;
**           PERSON.SSD on path1  for the PERSON   level file   ***;
**                                                              ***;
**  DELETE THE OLD DATASETs TO ALLOW ROOM FOR THE NEW ONEs.     ***;
**                                                              ***;
**                                                              ***;
**    path3   --> location of FARS Formats                      ***;
**                                                              ***;
*******************************************************************;

   LIBNAME  FARSDATA 'enter directory/filename of the sequential input file';
   FILENAME FARSTPL  'enter directory of the SAS data sets output folder';
   LIBNAME  LIBRARY  'enter directory of the formats library folder';



*******************************************************************;
**                                                              ***;
**  Note: The LIBRARY is needed only if FARS Formats are made   ***;
**        part of the input statement (see end of program).     ***;
**                                                              ***;
*******************************************************************;
OPTIONS  OBS=MAX ERRORS=10;
**;
**;
DATA ACC(KEEP=STATE      ST_CASE    CITY       COUNTY
              MONTH      DAY        YEAR       HOUR
              MINUTE     VE_FORMS   PERSONS    ROAD_FNC
              NHS        ROUTE      TWAY_ID    MILEPT
              SP_JUR     HARM_EV    MAN_COLL   REL_JUNC
              REL_ROAD   TRAF_FLO   NO_LANES   SP_LIMIT
              ALIGNMNT   PROFILE    PAVE_TYP   SUR_COND
              TRA_CONT   T_CONT_F   HIT_RUN    LGT_COND
              WEATHER    C_M_ZONE   NOT_HOUR   HOSP_HR
              HOSP_MN    NOT_MIN    ARR_HOUR   ARR_MIN
              SCH_BUS    CF1        CF2        CF3
              RAIL       LATITUDE   LONGITUD   FATALS
              DAY_WEEK   DRUNK_DR   PEDS)
     VEH(KEEP=STATE      ST_CASE    VEH_NO     MAKE
              MODEL      MAK_MOD    BODY_TYP   MOD_YEAR
              VIN_1      VIN_2      VIN_3      VIN_4
              VIN_5      VIN_6      VIN_7      VIN_8
              VIN_9      VIN_10     VIN_11     VIN_12
              REG_STAT   ROLLOVER   J_KNIFE    TRAV_SP
              HAZ_CARG   TOW_VEH    SPEC_USE   EMER_USE
              IMPACT1    IMPACT2    UNDERIDE   DEFORMED
              IMPACTS    TOWAWAY    FIRE_EXP   OCUPANTS
              DEATHS     VEH_CF1    VEH_CF2    VEH_MAN
              M_HARM     VINA_MOD   VIN_BT     VIN_WGT
              WHLBS_SH   WHLBS_LG   FLDCD_TR   WGTCD_TR
              SER_TR     VIN        MCYCL_DS   VIN_LNGT
              DR_PRES    DR_DRINK   L_STATE    L_COMPL
              L_STATUS   L_RESTRI   L_ENDORS   VIOLCHG1
              VIOLCHG2   VIOLCHG3   DR_WGT     DR_HGT
              PREV_ACC   PREV_SUS   PREV_DWI   PREV_SPD
              PREV_OTH   LAST_MO    LAST_YR    FIRST_MO
              FIRST_YR   DR_ZIP     DR_CF1     DR_CF2
              DR_CF3     DR_CF4     OWNER      V_CONFIG
              AXLES      MCARR_ID
              CARGO_BT   AVOID      CDL_STAT   VE_FORMS
              HARM_EV    MAN_COLL   HIT_RUN    MONTH)
     PER(KEEP=STATE      ST_CASE    VEH_NO     PER_NO
              N_MOT_NO   AGE        SEX        PER_TYP
              SEAT_POS   LOCATION   EJECTION   EXTRICAT
              ALC_DET    DRINKING   ATST_TYP   INJ_SEV
              HOSPITAL   DEATH_MO   DEATH_DA   DEATH_YR
              DEATH_TM   DEATH_HR   DEATH_MN   LAG_HRS
              LAG_MINS   P_CF1      P_CF2      P_CF3
              WORK_INJ   RACE       HISPANIC   COUNTY
              MONTH      DAY        HOUR       MINUTE
              VE_FORMS   ROAD_FNC   HARM_EV    MAN_COLL
              SCH_BUS    MAKE       MAK_MOD    BODY_TYP
              MOD_YEAR   ROLLOVER   TOW_VEH    SPEC_USE
              EMER_USE   IMPACT1    IMPACT2    IMPACTS
              FIRE_EXP   VINA_MOD   VIN_BT     VIN_WGT
              WHLBS_SH   WHLBS_LG   WGTCD_TR
              SER_TR     MCYCL_DS   REST_USE   DRUGS
              CERT_NO    AIR_BAG    DRUG_DET   DRUGTST1
              DRUGRES1   DRUGTST2   DRUGRES2   DRUGTST3
              DRUGRES3   ALC_RES    EJ_PATH);
**;
  LENGTH DEFAULT = 3;
  LENGTH STATE     COUNTY      MONTH     DAY
         HOUR      MINUTE      VE_FORMS  PERSONS   NHS
         ROAD_FNC  ROUTE       SP_JUR    HARM_EV   MAN_COLL
         REL_JUNC  REL_ROAD    TRAF_FLO  NO_LANES  SP_LIMIT
         ALIGNMNT  PROFILE     PAVE_TYP  SUR_COND  TRA_CONT
         T_CONT_F  HIT_RUN     LGT_COND  WEATHER   C_M_ZONE
         NOT_HOUR  NOT_MIN     ARR_HOUR  ARR_MIN   HOSP_HR
         HOSP_MN   SCH_BUS     CF1       CF2       CF3
         FATALS    DAY_WEEK    DRUNK_DR  UNDERIDE              3;
  LENGTH VEH_NO    MAKE        MODEL     BODY_TYP     3;
  LENGTH VIN_1     VIN_2       VIN_3     VIN_4     VIN_5
         VIN_6     VIN_7       VIN_8     VIN_9     VIN_10
         VIN_11    VIN_12      FLDCD_TR                      $ 1;
  LENGTH REG_STAT  ROLLOVER    J_KNIFE   TRAV_SP   HAZ_CARG
         TOW_VEH   SPEC_USE    EMER_USE  IMPACT1   IMPACT2
         DEFORMED  IMPACTS     TOWAWAY   FIRE_EXP  OCUPANTS
         DEATHS    VEH_CF1     VEH_CF2   VEH_MAN   M_HARM
         WGTCD_TR  VIN_LNGT    RACE      HISPANIC              3;
  LENGTH DR_PRES   DR_DRINK    L_STATE   L_STATUS  L_COMPL
         L_RESTRI  VIOLCHG1    VIOLCHG2  VIOLCHG3  PREV_ACC  PREV_SUS  PREV_DWI
         PREV_SPD  PREV_OTH    LAST_MO   FIRST_MO  DR_WGT    DR_HGT
         DR_CF1      DR_CF2    DR_CF3    DR_CF4                3;
  LENGTH VEH_NO    PER_NO      N_MOT_NO  AGE       SEX
         PER_TYP   SEAT_POS    LOCATION
         EJECTION  EXTRICAT    ALC_DET   DRINKING
         INJ_SEV     HOSPITAL  DEATH_MO  DEATH_DA
         DEATH_HR    DEATH_MN  LAG_HRS   LAG_MINS
         P_CF1     P_CF2       P_CF3     WORK_INJ  ATST_TYP    3;
  LENGTH ST_CASE   MILEPT      CITY      MAK_MOD   VIN_WGT DEATH_YR YEAR
         WHLBS_SH  WHLBS_LG    MCYCL_DS  DEATH_TM  DR_ZIP
         FIRST_YR  DEATH_YR    YEAR      MOD_YEAR  LAST_YR     4;
  LENGTH TWAY_ID                                            $ 20;
  LENGTH VIN                                                $ 12;
  LENGTH RAIL                                               $  7;
  LENGTH CERT_NO                                            $ 12;
  LENGTH SER_TR    VINA_MOD                                 $  3;
  LENGTH VIN_BT                                             $  2;
  LENGTH MCARR_ID                                           $ 11;
  LENGTH LATITUDE                                           $  8;
  LENGTH LONGITUD                                           $  9;
**;
  INFILE FARSTPL EOF=END_IT MISSOVER;
    RETAIN;
    INPUT @1  STATE      2.
          @8  FLD1     $ 2.
          @10 LEVEL      1.
          @11 FLD2     $ 2.
          @1  REC60    $ 60. @;
      IF MOD(_N_,1000) = 0 THEN PUT 'Processing Record : ' _N_;
      if 77000>_N_>76000 & mod(_N_,20)=0 then put 'Processing Record : ' _N_;
      if 81000>_N_>81050 then put @1 REC60;
***   IF STATE = '43' THEN DELETE;
      IF LEVEL = 1 THEN GOTO ACC_IN;
      IF LEVEL = 2 THEN GOTO VE_DR_IN;
      IF LEVEL = 3 THEN GOTO DR_IN;
      IF LEVEL = 4 THEN GOTO PER_IN;
      PUT '- - - - - - - - - - - - - - - - -';
      PUT 'LEVEL Number Error for ST_CASE= ' ST_CASE ' Level= ' LEVEL;
      PUT _N_ @10 REC60;
      RETURN;
**;
ACC_IN:
*     ;
INPUT    @1   STATE       2.       @1  ST_CASE         6.
         @13  CITY        4.       @17  COUNTY         3.
         @20  MONTH       2.       @22  DAY            2.
         @24  YEAR        4.       @28  HOUR           2.
         @30  MINUTE      2.       @32  VE_FORMS       2.
         @34  PERSONS     2.       @36  PEDS           2.
         @38  NHS         1.       @39  ROAD_FNC       2.
         @41  ROUTE       1.       @42  TWAY_ID    $  20.
         @62  MILEPT      5.       @67  SP_JUR         1.
         @68  HARM_EV     2.       @70  MAN_COLL       1.
         @71  REL_JUNC    2.       @73  REL_ROAD       2.
         @75  TRAF_FLO    1.       @76  NO_LANES       1.
         @77  SP_LIMIT    2.       @79  ALIGNMNT       1.
         @80  PROFILE     1.       @81  PAVE_TYP       1.
         @82  SUR_COND    1.       @83  TRA_CONT       2.
         @85  T_CONT_F    1.       @86  HIT_RUN        1.
         @87  LGT_COND    1.       @88  WEATHER        1.
         @89  C_M_ZONE    1.       @90  NOT_HOUR       2.
         @92  NOT_MIN     2.       @94  ARR_HOUR       2.
         @96  ARR_MIN     2.       @98  HOSP_HR        2.
         @100 HOSP_MN     2.       @102 SCH_BUS        1.
         @103 CF1         2.       @105 CF2            2.
         @107 CF3         2.       @109 RAIL        $  7.
         @116 LATITUDE  $ 8.       @124 LONGITUD    $  9.
         @133 FATALS      2.       @135 DAY_WEEK       1.
         @136 DRUNK_DR    1.;
**;
         MAKE     = . ;
         MAK_MOD  = . ;
         BODY_TYP = . ;
         MOD_YEAR = . ;
         ROLLOVER = . ;
         TOW_VEH  = . ;
         SPEC_USE = . ;
         EMER_USE = . ;
         IMPACT1  = . ;
         IMPACT2  = . ;
         IMPACTS  = . ;
         FIRE_EXP = . ;
         VINA_MOD = '   ';
         VIN_BT   = '  ' ;
         VIN_WGT  = . ;
         WHLBS_SH = . ;
         WHLBS_LG = . ;
         WGTCD_TR = . ;
         SER_TR   = '   ';
         MCYCL_DS = . ;
         OUTPUT ACC;
         ACCIDENT+1;
         RETURN;
**;
VE_DR_IN:
        DUM_FLG = 0;
        IF FLD1 = '00' THEN DO ;
          VEH_DUMM + 1;
          DUM_FLG = 1;
          DELETE;
        END;
INPUT    @8  VEH_NO        2.      @13   OCUPANTS      2.
         @15  MAKE         2.      @17   MODEL         3.
         @15  MAK_MOD      5.      @20   BODY_TYP      2.
         @22  MOD_YEAR     4.      @26   VIN_1      $  1.
         @27  VIN_2      $ 1.      @28   VIN_3      $  1.
         @29  VIN_4      $ 1.      @30   VIN_5      $  1.
         @31  VIN_6      $ 1.      @32   VIN_7      $  1.
         @33  VIN_8      $ 1.      @34   VIN_9      $  1.
         @35  VIN_10     $ 1.      @36   VIN_11     $  1.
         @37  VIN_12     $ 1.      @26   VIN        $ 12.
         @38  REG_STAT     2.      @40   OWNER         1.
         @41  ROLLOVER     1.      @42   J_KNIFE       1.
         @43  TRAV_SP ??   2.      @45   HAZ_CARG      1.
         @46  TOW_VEH      1.      @47   V_CONFIG      1.
         @48  AXLES        2.      @50   CARGO_BT      2.
         @52  SPEC_USE     1.      @53   EMER_USE      1.
         @54  IMPACT1      2.      @56   IMPACT2       2.
         @58  UNDERIDE     1.      @59   DEFORMED      1.
         @60  IMPACTS      1.      @61   TOWAWAY       1.
         @62  FIRE_EXP     1.      @63   VEH_CF1       2.
         @65  VEH_CF2      2.      @67   VEH_MAN       2.
         @69  AVOID        1.      @70   M_HARM        2.
         @72  MCARR_ID    11.
         @83  DEATHS       2.      @85   VINA_MOD   $  3.
         @88  VIN_BT     $ 2.      @90   VIN_WGT   ??  4.
         @94  WHLBS_SH  ?? 4.      @98   WHLBS_LG  ??  4.
         @102 FLDCD_TR   $ 1.      @103  WGTCD_TR  ??  1.
         @104 SER_TR     $ 3.      @107  MCYCL_DS ??   4.
         @111 VIN_LNGT  ?? 2.;
         VEHICLE + 1;
         RETURN;
**;
DR_IN:
          IF FLD1 = '00'  AND DUM_FLG = 1 THEN DO ;
            DR_DUMM + 1;
            DELETE;
            END;
          IF FLD1 = '00' AND DUM_FLG = 0 THEN DO;
            DR_PRES  = .;  DR_DRINK = .;  L_STATE  = .  ;  L_STATUS = .;
            L_RESTRI = .;  VIOLCHG1 = .;  VIOLCHG2 = .  ;  VIOLCHG3 = .;
            PREV_ACC = .;  PREV_SUS = .;
            PREV_DWI = .;  PREV_SPD = .;  PREV_OTH = .  ;  LAST_MO  = .;
            LAST_YR  = .;  FIRST_MO = .;  FIRST_YR = .  ;  DR_CF1   = .;
            DR_CF2   = .;  DR_CF3   = .;  DR_CF4   = .  ;  L_COMPL  = .;
            DR_ZIP   = .;
            DR_DUMM + 1;
            OUTPUT VEH;
            RETURN;
          END;
INPUT     @13  DR_PRES        1.    @14    DR_DRINK       1.
          @15  L_STATE        2.    @17    L_STATUS       1.
          @18  CDL_STAT       1.    @19    L_ENDORS       1.
          @20  L_COMPL        1.    @21    L_RESTRI       1.
          @22  VIOLCHG1       2.    @24    VIOLCHG2       2.
          @26  VIOLCHG3       2.    @28    PREV_ACC       2.
          @30  PREV_SUS       2.    @32    PREV_DWI       2.
          @34  PREV_SPD       2.    @36    PREV_OTH       2.
          @38  LAST_MO        2.    @40    LAST_YR        4.
          @44  FIRST_MO       2.    @46    FIRST_YR       4.
          @50  DR_ZIP         5.    @55    DR_CF1         2.
          @57  DR_CF2         2.    @59    DR_CF3         2.
          @61  DR_CF4         2.    @63    DR_WGT         3.
          @66  DR_HGT         3.;
            DRIVER + 1;
            OUTPUT VEH;
            RETURN;
**;
PER_IN:
        IF FLD2 = '00' THEN DO;
          PER_DUMM + 1;
          DELETE;
        END;
INPUT   @8    VEH_NO       2.    @11    PER_NO      2.
        @13   N_MOT_NO     2.    @15    AGE         2.
        @17   SEX          1.    @18    PER_TYP     2.
        @20   SEAT_POS     2.    @22    REST_USE    2.
        @24   AIR_BAG      2.    @26    EJECTION    1.
        @27   EJ_PATH      1.    @28    EXTRICAT    1.
        @29   LOCATION     2.    @31    DRINKING    1.
        @32   ALC_DET      1.    @33    ATST_TYP    1.
        @34   ALC_RES      2.
        @36   DRUGS        1.    @37    DRUG_DET    1.
        @38   DRUGTST1     1.    @39    DRUGRES1    3.
        @42   DRUGTST2     1.    @43    DRUGRES2    3.
        @46   DRUGTST3     1.    @47    DRUGRES3    3.
        @50   INJ_SEV      1.    @51    HOSPITAL    1.
        @52   DEATH_MO     2.    @54    DEATH_DA    2.
        @56   DEATH_YR     4.    @60    DEATH_TM ?? 4.
        @60   DEATH_HR ??  2.    @62    DEATH_MN ?? 2.
        @64   LAG_HRS ??   3.    @67    LAG_MINS ?? 2.
        @69   P_CF1        2.    @71    P_CF2       2.
        @73   P_CF3        2.    @75    CERT_NO  $ 12.
        @87   WORK_INJ     1.    @88    RACE        2.
        @90   HISPANIC     2.;
        PERSON + 1;
        OUTPUT PER;
        RETURN;
**;
END_IT:
        PUT '                - - - - - - - - ';
        PUT'        **    RUN TIME STATISTICS     ***';
        PUT '                - - - - - - - - ';
        PUT '     TOTAL ACCIDENT RECORDS READ........' ACCIDENT;
        PUT '     TOTAL VEHICLE RECORDS READ.........' VEHICLE;
        PUT '     TOTAL DRIVER RECORDS READ..........' DRIVER;
        PUT '     TOTAL PERSON RECORDS READ..........' PERSON;
        PUT '     TOTAL DUMMY VEHICLE RECORDS READ...' VEH_DUMM;
        PUT '     TOTAL DUMMY DRIVER RECORDS READ....' DR_DUMM;
        PUT '     TOTAL DUMMY PERSON RECORDS READ....' PER_DUMM;
        PUT  '   ';
        STOP;
******************************************************************;
**;
LABEL
     VE_FORMS = 'VEHICLE FORMS SUBMITTED'
     PEDS     = 'NON-MOTORIST FORMS SUBMITTED'
     ROUTE    = 'ROUTE SIGNING'
     ROAD_FNC = 'RDWY FUNCTION CLASS'
     NO_LANES = 'LANES'
     SP_LIMIT = 'SPEED LIMIT'
     PROFILE  = 'ROADWAY PROFILE'
     PAVE_TYP = 'ROADWAY SURFACE TYPE'
     SUR_COND = 'SURFACE CONDITION'
     TRA_CONT = 'TRAFFIC CONTROLS'
     LGT_COND = 'LIGHT CONDITION'
     C_M_ZONE = 'CONSTR/MAINT ZONE'
     SCH_BUS  = 'SCHOOLBUS RELATED'
     CF1      = 'RELATED FACTOR 1'
     CF2      = 'RELATED FACTOR 2'
     CF3      = 'RELATED FACTOR 3'
     RAIL     = 'RAIL XING ID'
     FATALS   = 'FATALITIES'
     ALIGNMNT = 'ROADWAY ALIGNMENT'
     DAY_WEEK = 'DAY OF WEEK'
     HARM_EV  = 'FIRST HARMFUL EVENT'
     HIT_RUN  = 'HIT AND RUN'
     MAN_COLL = 'MANNER OF COLLISION'
     MILEPT   = 'MILEPOINT'
     REL_JUNC = 'RELATION TO JUNCTION'
     REL_ROAD = 'RELATION TO ROADWAY'
     SP_JUR   = 'SPECIAL JURISDICTION'
     T_CONT_F = 'CONTROLS FUNCTIONING'
     TRAF_FLO = 'TRAFFICWAY FLOW'
     TWAY_ID  = 'TRAFFICWAY ID'
     DRUNK_DR = 'DRUNK DRIVERS'
     LATITUDE = 'GLOBAL POSITION, LATITUDE'
     LONGITUD = 'GLOBAL POSITION, LONGITUDE';
LABEL
     BODY_TYP = 'BODY TYPE'
     MOD_YEAR = 'MODEL YEAR'
     REG_STAT = 'REGISTRATION STATE'
     J_KNIFE  = 'JACKKNIFE'
     TRAV_SP  = 'TRAVEL SPEED'
     TOW_VEH  = 'TOWED TRAILING UNIT'
     SPEC_USE = 'SPECIAL USE'
     EMER_USE = 'EMERGENCY USE'
     IMPACT1  = 'INITIAL IMPACT'
     IMPACT2  = 'PRINCIPAL IMPACT'
     UNDERIDE = 'UNDERRIDE/OVERRIDE'
     DEFORMED = 'DEFORMATION'
     IMPACTS  = 'VEHICLE ROLE'
     TOWAWAY  = 'MANNER LEAVING SCENE'
     FIRE_EXP = 'FIRE OCCURRENCE'
     OCUPANTS = 'OCCUPANTS'
     DEATHS   = 'FATALS IN VEHICLE'
     VEH_CF1  = 'RELATED FACTOR 1'
     VEH_CF2  = 'RELATED FACTOR 2'
     M_HARM   = 'MOST HARMFUL EVENT'
     AVOID    = 'CRASH AVOIDANCE MANUEVER'
     CARGO_BT = 'CARGO BODY TYPE'
     AXLES    = 'NUMBER OF AXLES'
     V_CONFIG = 'VEHICLE CONFIGURATION'
     OWNER    = 'REGISTERED VEHICLE OWNER'
     VIN_WGT  = 'VIN WEIGHT-AUTO'
     WHLBS_SH = 'WHLBASE SHORT-AUTO'
     WHLBS_LG = 'WHLBASE LONG-AUTO'
     VINA_MOD = 'VIN MODEL'
     DR_DRINK = 'DRIVER DRINKING'
     FLDCD_TR = 'TRUCK FUEL CODE'
     WGTCD_TR = 'TRUCK WEIGHT CODE'
     SER_TR   = 'VIN SERIES TRUCK'
     MCYCL_DS = 'CC DISPLACEMENT'
     VIN_LNGT = 'VIN LENGTH'
     HAZ_CARG = 'HAZARDOUS CARGO'
     DR_PRES  = 'DRIVER PRESENCE'
     L_STATE  = 'LICENSE STATE'
     L_STATUS = 'NON-CDL LICENCE STATUS'
     L_ENDORS = 'COMPLIANCE W/LIC ENDORSEMENTS'
     L_RESTRI = 'COMPLIANCE W/LIC RESTRICTIONS'
     CDL_STAT = 'COMM MV LICENCE STATUS'
     VIOLCHG1 = 'VIOLATION CHARGE 1'
     VIOLCHG2 = 'VIOLATION CHARGE 2'
     VIOLCHG3 = 'VIOLATION CHARGE 3'
     L_COMPL  = 'DRIVER LICENCE TYPE COMPLIANCE'
     PREV_ACC = 'PREVIOUS ACCIDENTS'
     PREV_SUS = 'PREVIOUS SUSPENSIONS'
     PREV_DWI = 'PREVIOUS DWI'
     DR_ZIP   = 'DRIVER ZIP CODE'
     PREV_SPD = 'PREVIOUS SPEEDING'
     PREV_OTH = 'PREV OTH MV CONVICTIONS'
     LAST_MO  = 'LAST ACCIDENT-MONTH'
     LAST_YR  = 'LAST ACCIDENT-YEAR'
     FIRST_MO = 'FIRST ACCIDENT-MONTH'
     FIRST_YR = 'FIRST ACCIDENT-YEAR'
     DR_CF1   = 'RELATED FACTOR 1'
     DR_CF2   = 'RELATED FACTOR 2'
     MAK_MOD  = 'VEHICLE MODEL'
     VEH_MAN  = 'VEHICLE MANEUVER'
     DR_CF3   = 'RELATED FACTOR 3'
     DR_CF4   = 'RELATED FACTOR 4'
     MCARR_ID = 'MOTOR CARRIER ID'
     DR_WGT   = 'DRIVER WEIGHT'
     DR_HGT   = 'DRIVER HEIGHT';
LABEL
     PER_TYP  = 'PERSON TYPE'
     SEAT_POS = 'SEATING POSITION'
     REST_USE = 'RESTRAINT SYSTEM USE'
     AIR_BAG  = 'AIR BAG AVAILABILITY/FUNCTION'
     LOCATION = 'NON-MOTORIST LOCATION'
     EJ_PATH  = 'EJECTION PATH'
     EXTRICAT = 'EXTRICATION'
     ALC_DET  = 'ALCOHOL DETERMINATION'
     ATST_TYP = 'ALCOHOL TEST TYPE'
     DRINKING = 'ALCOHOL INVOLVEMENT'
     ALC_RES  = 'ALCOHOL TEST RESULTS'
     DRUGS    = 'DRUG INVOLVEMENT'
     DRUG_DET = 'DRUG DETERMAINATION'
     DRUGTST1 = 'DRUG TEST TYPE-1'
     DRUGRES1 = 'DRUG TEST RESULTS-1'
     DRUGTST2 = 'DRUG TEST TYPE-2'
     DRUGRES2 = 'DRUG TEST RESULTS-2'
     DRUGTST3 = 'DRUG TEST TYPE-3'
     DRUGRES3 = 'DRUG TEST RESULTS-3'
     CERT_NO  = 'DEATH CERTIFICATE'
     HOSPITAL = 'TAKEN TO HOSPITAL'
     PER_NO   = 'PERSON #'
     VEH_NO   = 'VEHICLE #'
     WORK_INJ = 'FATAL AT WORK'
     N_MOT_NO = 'STRIKING VEHICLE'
     INJ_SEV  = 'INJURY SEVERITY'
     P_CF1    = 'RELATED FACTOR 1'
     P_CF2    = 'RELATED FACTOR 2'
     P_CF3    = 'RELATED FACTOR 3'
     HISPANIC = 'HISPANIC ORIGIN';

**;
FORMAT   STATE    FSTATES.    MAN_COLL FCOLL.      TRAF_FLO FFLOW82F.
         LGT_COND FLIGHT.     WEATHER  FATM82F.    SUR_COND FSURFCON.
         ROUTE    FRTSIGN.    REL_JUNC FJUNCT.     REL_ROAD FRDWY98F.
         ALIGNMNT FALIG.      PROFILE  FGRAD82F.   PAVE_TYP FPAVE.
         HIT_RUN  FHIT82F.    C_M_ZONE FCMZ82F.    SP_JUR   FSPECJUR.
         CF1      FARF82F.    CF2      FARF82F.    CF3      FARF82F.
         DR_CF1   FDRF98F.    DR_CF2   FDRF98F.    DR_CF3   FDRF98F.
         DR_CF4   FDRF98F.
         P_CF1    FPRF98F.    P_CF2    FPRF98F.    P_CF3    FPRF98F.
         WORK_INJ FWORKINJ.   TRA_CONT FTRCN82F.   MONTH    FACMONTH.
         ROAD_FNC FRFC87F.    HARM_EV  FFHE82F.    SCH_BUS  FYESNO.
         DAY_WEEK FDAYS.      MAKE     FMAKE91F.   BODY_TYP FBODY91F.
         ROLLOVER FROLL.      TOW_VEH  FVTOW87F.   SPEC_USE FSPECIAL.
         IMPACT1  FIMPACTA.   IMPACT2  FIMPACTA.   IMPACTS  FIMPAC.
         FIRE_EXP FFIRE.      VEH_CF1  FVRF.       VEH_CF2  FVRF.
         EJ_PATH  FEPATH.     DRUG_DET FDRUGDET.   DRUGTST1 FDR_TEST.
         DRUGRES1 FDR93RES.   DRUGTST2 FDR_TEST.   DRUGRES2 FDR93RES.
         DRUGTST3 FDR_TEST.   DRUGRES3 FDR93RES.   CDL_STAT FCDL93F.
         V_CONFIG FVCON95F.   CARGO_BT FCBT95F.    AVOID    FCAVOID.
         OWNER    FROWNER.    REG_STAT FREG_ST.    L_STATE  FSTATES.
         DEFORMED FEDEFORM.   TOWAWAY  FTOW82F.    M_HARM   FFHE82F.
         DR_PRES  FDRIVER.    L_STATUS FLST93F.    L_RESTRI FLREST.
         VIOLCHG1 FVCHG97F.   VIOLCHG2 FVCHG97F.   VIOLCHG3 FVCHG97F.
         LAST_MO  FACMONTH.   FIRST_MO FACMONTH.   ATST_TYP FTESTTYP.
         TRAV_SP  FTSPEED.    EMER_USE FYESNO.     J_KNIFE  FJK82F.
         PER_TYP  FPTYP94F.   REST_USE FRUSE94F.   AIR_BAG  FAIRB98F.
         EJECTION FEJECT.     INJ_SEV  FINJURY.    SEX      FSEXX.
         LOCATION FPLOC82F.   SEAT_POS FSEAT82F.   ALC_DET  FALC_D.
         DRINKING FDRINK.     EXTRICAT FEXTR.      HOSPITAL FYESNO.
         DRUGS    FDRUGS.     ALC_RES  FT_RES.     N_MOT_NO FNONMOT.
         NHS      FNHS94F.    T_CONT_F FTCFUNC.    HAZ_CARG FHAZ.
         VEH_MAN  FV_MAN.     L_COMPL  FCOM87F.    DR_DRINK FDRIVEDR.
         AXLES    FAXLES.     L_ENDORS FEND91F.    UNDERIDE FURIDE.
         RACE     FRACE.      HISPANIC FHISPAN.    HOSPITAL FHOSPIT.
         MAK_MOD  FMKMD91F.;
*    ;
RUN;
***********************************************************************;
* PROC COPY IN=WORK OUT=FARSDATA;
PROC SORT DATA=PER OUT=FARSDATA.PERSON;
      BY ST_CASE VEH_NO PER_NO;
RUN;
PROC SORT DATA=ACC OUT=FARSDATA.ACCIDENT;
      BY ST_CASE;
RUN;
PROC SORT DATA=VEH OUT=FARSDATA.VEHICLE;
      BY ST_CASE VEH_NO;
RUN;
**;
PROC CONTENTS DATA=FARSDATA._ALL_;
RUN;
